This module includes a simple function to retrieve the digits of [_A Million Random Digits with 100,000 Normal Deviates_](https://www.rand.org/pubs/monograph_reports/MR1418.html) by RAND Corporation.

### Usage
```
import randbyrand

digits = randbyrand.get_digits()
```